@@ -301,16 +301,6 @@ extern "C" {
       ((type *) g_realloc (mem, (unsigned) sizeof (type) * (count)))
 #endif /* __DMALLOC_H__ */
 
-/* alloca-based counterparts of the above routines */
-#if G_HAVE_ALLOCA
-#  define g_alloca alloca
-#  define g_new_a(type, count)	  \
-      ((type *) alloca ((unsigned) sizeof (type) * (count)))
-#  define g_new0_a(type, count)	  \
-      ((type *) memset (alloca ((unsigned) sizeof (type) * (count)), 0, \
-      			((unsigned) sizeof (type) * (count))))
-#endif
-
 #define g_mem_chunk_create(type, pre_alloc, alloc_type)	( \
   g_mem_chunk_new (#type " mem chunks (" #pre_alloc ")", \
 		   sizeof (type), \
@@ -1122,6 +1112,8 @@ typedef enum
   G_HOOK_FLAG_MASK	= 0x0f
 } GHookFlagMask;
 
+#define	G_HOOK_DEFERRED_DESTROY	((GHookFreeFunc) 0x01)
+
 struct _GHookList
 {
   guint		 seq_id;
@@ -1130,6 +1122,7 @@ struct _GHookList
   GHook		*hooks;
   GMemChunk	*hook_memchunk;
   GHookFreeFunc	 hook_free; /* virtual function */
+  GHookFreeFunc	 hook_destroy; /* virtual function */
 };
 
 struct _GHook
@@ -1270,7 +1263,7 @@ GLogLevelFlags	g_log_set_fatal_mask	(const gchar	*log_domain,
 					 GLogLevelFlags	 fatal_mask);
 GLogLevelFlags	g_log_set_always_fatal	(GLogLevelFlags	 fatal_mask);
 #ifndef	G_LOG_DOMAIN
-#define	G_LOG_DOMAIN	(NULL)
+#define	G_LOG_DOMAIN	((gchar*) 0)
 #endif	/* G_LOG_DOMAIN */
 #ifdef	__GNUC__
 #define	g_error(format, args...)	g_log (G_LOG_DOMAIN, \
@@ -1283,7 +1276,7 @@ GLogLevelFlags	g_log_set_always_fatal	(GLogLevelFlags	 fatal_mask);
 					       G_LOG_LEVEL_WARNING, \
 					       format, ##args)
 #else	/* !__GNUC__ */
-static inline void
+static void
 g_error (const gchar *format,
 	 ...)
 {
@@ -1292,7 +1285,7 @@ g_error (const gchar *format,
   g_logv (G_LOG_DOMAIN, G_LOG_LEVEL_ERROR, format, args);
   va_end (args);
 }
-static inline void
+static void
 g_message (const gchar *format,
 	   ...)
 {
@@ -1301,7 +1294,7 @@ g_message (const gchar *format,
   g_logv (G_LOG_DOMAIN, G_LOG_LEVEL_MESSAGE, format, args);
   va_end (args);
 }
-static inline void
+static void
 g_warning (const gchar *format,
 	   ...)
 {
@@ -1465,54 +1458,6 @@ gchar*	 g_strescape		(gchar	      *string);
 gpointer g_memdup		(gconstpointer mem,
 				 guint	       byte_size);
 
-/* Macros for dynamic strings via fast stack allocation
- * All macros take a special first argument: the target gchar* string
- */
-#if G_HAVE_ALLOCA
-
-#  define g_strdup_a(newstr,str) G_STMT_START { \
-	  if ((str) == NULL) (newstr) = NULL;	\
-	  else {				\
-	    const char *__old = (str);		\
-	    char *__new;			\
-	    size_t __len = strlen (__old) + 1;	\
-	    __new = alloca (__len);		\
-	    memcpy (__new, __old, __len);	\
-	    (newstr) = __new;			\
-   	  }					\
-   } G_STMT_END
-
-#  define g_strndup_a(newstr,str,n) G_STMT_START { \
-	  if ((str) == NULL) (newstr) = NULL;	\
-	  else {				\
-	    const char *__old = (str);		\
-	    char *__new;			\
-	    size_t __len = strlen (__old);	\
-	    if (__len > (n)) __len = (n);	\
-	    __new = alloca (__len + 1);		\
-	    memcpy (__new, __old, __len);	\
-	    __new[__len] = 0;			\
-	    (newstr) = __new;			\
-   	  }					\
-   } G_STMT_END
-
-#  define g_strconcat3_a(newstr,str1,str2,str3) G_STMT_START { \
-	  size_t __len1 = ((str1) == (gchar*)NULL) ? 0 : strlen((str1)); \
-	  size_t __len2 = ((str2) == (gchar*)NULL) ? 0 : strlen((str2)); \
-	  size_t __len3 = ((str3) == (gchar*)NULL) ? 0 : strlen((str3)); \
-	  char *__sptr, *__new = \
-	  	alloca (__len1 + __len2 + __len3 + 1); \
-	  __sptr = __new; \
-	  if (__len1){memcpy (__sptr, (str1), __len1); __sptr += __len1;} \
-	  if (__len2){memcpy (__sptr, (str2), __len2); __sptr += __len2;} \
-	  if (__len3){memcpy (__sptr, (str3), __len3); __sptr += __len3;} \
-	  *__sptr = '\0'; \
-	  (newstr) = __new; \
-   } G_STMT_END
-
-#endif /* G_HAVE_ALLOCA */
-
-
 /* NULL terminated string arrays.
  * g_strsplit() splits up string into max_tokens tokens at delim and
  * returns a newly allocated string array.
@@ -1689,7 +1634,7 @@ void	 g_string_sprintfa  (GString	 *string,
 
 #define g_array_append_val(a,v) g_array_append_vals(a,&v,1)
 #define g_array_prepend_val(a,v) g_array_prepend_vals(a,&v,1)
-#define g_array_insert_val(a,i,v) g_array_prepend_vals(a,i,&v,1)
+#define g_array_insert_val(a,i,v) g_array_insert_vals(a,i,&v,1)
 #define g_array_index(a,t,i) (((t*)a->data)[i])
 
 GArray* g_array_new	          (gboolean	    zero_terminated,
@@ -2460,15 +2405,17 @@ struct _GSourceFuncs
 typedef gboolean (*GSourceFunc) (gpointer data);
 
 /* Hooks for adding to the main loop */
-guint g_source_add                  (gint           priority, 
-				     gboolean       can_recurse,
-				     GSourceFuncs  *funcs,
-				     gpointer       source_data, 
-				     gpointer       user_data,
-				     GDestroyNotify notify);
-void g_source_remove                (guint          tag);
-void g_source_remove_by_user_data   (gpointer       user_data);
-void g_source_remove_by_source_data (gpointer       source_data);
+guint    g_source_add                        (gint           priority, 
+					      gboolean       can_recurse,
+					      GSourceFuncs  *funcs,
+					      gpointer       source_data, 
+					      gpointer       user_data,
+					      GDestroyNotify notify);
+gboolean g_source_remove                     (guint          tag);
+gboolean g_source_remove_by_user_data        (gpointer       user_data);
+gboolean g_source_remove_by_source_data      (gpointer       source_data);
+gboolean g_source_remove_by_funcs_user_data  (GSourceFuncs  *funcs,
+					      gpointer       user_data);
 
 void g_get_current_time		    (GTimeVal	   *result);
 
@@ -2502,10 +2449,30 @@ guint	   	g_idle_add_full		(gint   	priority,
 					 GSourceFunc	function,
 					 gpointer	data,
 					 GDestroyNotify destroy);
+gboolean	g_idle_remove_by_data	(gpointer	data);
 
 /* GPollFD
  *
- * Unix-specific IO and main loop calls
+ * System-specific IO and main loop calls
+ *
+ * On Win32, the fd in a GPollFD should be Win32 HANDLE (*not* a file
+ * descriptor as provided by the C runtime) that can be used by
+ * MsgWaitForMultipleObjects. This does *not* include file handles
+ * from CreateFile, SOCKETs, nor pipe handles. (But you can use
+ * WSAEventSelect to signal events when a SOCKET is readable).
+ *
+ * On Win32, fd can also be the special value G_WIN32_MSG_HANDLE to
+ * indicate polling for messages. These message queue GPollFDs should
+ * be added with the g_main_poll_win32_msg_add function.
+ *
+ * But note that G_WIN32_MSG_HANDLE GPollFDs should not be used by GDK
+ * (GTK) programs, as GDK itself wants to read messages and convert them
+ * to GDK events.
+ *
+ * So, unless you really know what you are doing, it's best not to try
+ * to use the main loop polling stuff for your own needs on
+ * Win32. It's really only written for the GIMP's needs so
+ * far.
  */
 
 typedef struct _GPollFD GPollFD;
@@ -2524,45 +2491,77 @@ void        g_main_add_poll          (GPollFD    *fd,
 void        g_main_remove_poll       (GPollFD    *fd);
 void        g_main_set_poll_func     (GPollFunc   func);
 
+/* On Unix, IO channels created with this function for any file
+ * descriptor or socket.
+ *
+ * On Win32, use this only for plain files opened with the MSVCRT (the
+ * Microsoft run-time C library) _open(), including file descriptors
+ * 0, 1 and 2 (corresponding to stdin, stdout and stderr).
+ * Actually, don't do even that, this code isn't done yet.
+ *
+ * The term file descriptor as used in the context of Win32 refers to
+ * the emulated Unix-like file descriptors MSVCRT provides.
+ */
 GIOChannel* g_io_channel_unix_new    (int         fd);
 gint        g_io_channel_unix_get_fd (GIOChannel *channel);
 
-
-/* old IO Channels */
-#if 0
-/* IO Channels.
- * These are used for plug-in communication in the GIMP, for instance.
- * On Unix, it's simply an encapsulated file descriptor (a pipe).
- * On Windows, it's a handle to an anonymouos pipe, *and* (in the case
- * of the writable end) a thread id to post a message to when you have written
- * stuff.
- */
-struct _GIOChannel
-{
-  gint fd;			/* file handle (pseudo such in Win32) */
 #ifdef NATIVE_WIN32
-  guint peer;			/* thread to post message to */
-  guint peer_fd;		/* read handle (in the other process) */
-  guint offset;			/* counter of accumulated bytes, to
-				 * be included in the message posted
-				 * so we keep in sync.
-				 */
-  guint need_wakeups;		/* in output channels whether the reader
-				 * needs wakeups
-				 */
-#endif
-};
-GIOChannel *g_iochannel_new            (gint        fd);
-void        g_iochannel_free           (GIOChannel *channel);
-void        g_iochannel_close_and_free (GIOChannel *channel);
-void        g_iochannel_wakeup_peer    (GIOChannel *channel);
-#ifndef NATIVE_WIN32
-#  define   g_iochannel_wakeup_peer(channel) G_STMT_START { } G_STMT_END
-#endif
-#endif	/* old IO Channels */
 
+GUTILS_C_VAR guint g_pipe_readable_msg;
 
-/* Windows emulation stubs for common unix functions
+#define G_WIN32_MSG_HANDLE 19981206
+
+/* This is used to add polling for Windows messages. GDK (GTk+) programs
+ * should *not* use this. (In fact, I can't think of any program that
+ * would want to use this, but it's here just for completeness's sake.
+ */
+void        g_main_poll_win32_msg_add(gint        priority,
+				      GPollFD    *fd,
+				      guint       hwnd);
+
+/* An IO channel for Windows messages for window handle hwnd. */
+GIOChannel *g_io_channel_win32_new_messages (guint hwnd);
+
+/* An IO channel for an anonymous pipe as returned from the MSVCRT
+ * _pipe(), with no mechanism for the writer to tell the reader when
+ * there is data in the pipe.
+ *
+ * This is not really implemented yet.
+ */
+GIOChannel *g_io_channel_win32_new_pipe (int fd);
+
+/* An IO channel for a pipe as returned from the MSVCRT _pipe(), with
+ * Windows user messages used to signal data in the pipe for the
+ * reader.
+ *
+ * fd is the file descriptor. For the write end, peer is the thread id
+ * of the reader, and peer_fd is his file descriptor for the read end
+ * of the pipe.
+ *
+ * This is used by the GIMP, and works.
+ */
+GIOChannel *g_io_channel_win32_new_pipe_with_wakeups (int   fd,
+						      guint peer,
+						      int   peer_fd);
+
+void        g_io_channel_win32_pipe_request_wakeups (GIOChannel *channel,
+						     guint       peer,
+						     int         peer_fd);
+
+void        g_io_channel_win32_pipe_readable (int   fd,
+					      guint offset);
+
+/* Get the C runtime file descriptor of a channel. */
+gint        g_io_channel_win32_get_fd (GIOChannel *channel);
+
+/* An IO channel for a SOCK_STREAM winsock socket. The parameter is
+ * actually a SOCKET.
+ */
+GIOChannel *g_io_channel_win32_new_stream_socket (int socket);
+
+#endif
+
+/* Windows emulation stubs for common Unix functions
  */
 #ifdef NATIVE_WIN32
 #  define MAXPATHLEN 1024
