@@ -91,8 +91,16 @@ static gchar*
 _g_module_build_path (const gchar *directory,
 		      const gchar *module_name)
 {
-  if (directory)
-    return g_strconcat (directory, "\\", module_name, ".dll", NULL);
+  gint k;
+
+  k = strlen (module_name);
+  if (directory && *directory)
+    if (k > 4 && g_strcasecmp (module_name + k - 4, ".dll") == 0)
+      return g_strconcat (directory, "\\", module_name, NULL);
+    else
+      return g_strconcat (directory, "\\", module_name, ".dll", NULL);
+  else if (k > 4 && g_strcasecmp (module_name + k - 4, ".dll") == 0)
+    return g_strdup (module_name);
   else
     return g_strconcat (module_name, ".dll", NULL);
 }
