@@ -413,9 +413,45 @@ g_get_any_init (void)
 #endif /* NATIVE_WIN32 */
 	}
       
+#ifdef NATIVE_WIN32
+      /* The official way to specify a home directory on NT is
+       * the HOMEDRIVE and HOMEPATH environment variables.
+       *
+       * This is inside #ifdef NATIVE_WIN32 because with the cygwin dll,
+       * HOME should be a POSIX style pathname.
+       */
+      
+      if (getenv ("HOMEDRIVE") != NULL && getenv ("HOMEPATH") != NULL)
+	{
+	  gchar *homedrive, *homepath;
+
+	  homedrive = g_strdup (g_getenv ("HOMEDRIVE"));
+	  homepath = g_strdup (g_getenv ("HOMEPATH"));
+
+	  g_home_dir = g_strconcat (homedrive, homepath, NULL);
+	  g_free (homedrive);
+	  g_free (homepath);
+	}
+      if (!g_home_dir)
+	g_home_dir = g_strdup (g_getenv ("HOME"));
+#else
       g_home_dir = g_strdup (g_getenv ("HOME"));
+#endif
       
 #ifdef HAVE_PWD_H
+      /* FIXME: we must actually use the getpwuid_r function here, as
+	 getpwuid is not MT-safe, but the prototype doesn't seem to be
+	 agreed upon on the different systems, i.e. it is
+
+	 struct passwd *getpwuid_r(uid_t uid, struct passwd * pwd, 
+	                           char *buffer, int buflen); 
+
+         on solaris, but 
+	 
+	 int getpwuid_r(uid_t uid, struct passwd *pwd, char *buffer, 
+	                size_t bufsize  struct passwd **result); 
+ 
+         on posix. weird. */
       setpwent ();
       pw = getpwuid (getuid ());
       endpwent ();
