@@ -42,11 +42,6 @@ else \
 #define GLIB_TEST_STRING "el dorado "
 #define GLIB_TEST_STRING_5 "el do"
 
-typedef struct {
-	guint age;
-	gchar name[40];
-} GlibTestInfo;
-
 static gboolean
 node_build_string (GNode    *node,
 		   gpointer  data)
@@ -185,7 +180,7 @@ g_node_test (void)
     g_print ("ok\n");
 }
 
-gboolean
+static gboolean
 my_hash_callback_remove (gpointer key,
 			 gpointer value,
 			 gpointer user_data)
@@ -198,7 +193,7 @@ my_hash_callback_remove (gpointer key,
   return FALSE;
 }
 
-void
+static void
 my_hash_callback_remove_test (gpointer key,
 			      gpointer value,
 			      gpointer user_data)
@@ -209,7 +204,7 @@ my_hash_callback_remove_test (gpointer key,
     g_print ("bad!\n");
 }
 
-void
+static void
 my_hash_callback (gpointer key,
 		  gpointer value,
 		  gpointer user_data)
@@ -218,20 +213,20 @@ my_hash_callback (gpointer key,
   *d = 1;
 }
 
-guint
+static guint
 my_hash (gconstpointer key)
 {
   return (guint) *((const gint*) key);
 }
 
-gint
+static gint
 my_hash_compare (gconstpointer a,
 		 gconstpointer b)
 {
   return *((const gint*) a) == *((const gint*) b);
 }
 
-gint
+static gint
 my_list_compare_one (gconstpointer a, gconstpointer b)
 {
   gint one = *((const gint*)a);
@@ -239,7 +234,7 @@ my_list_compare_one (gconstpointer a, gconstpointer b)
   return one-two;
 }
 
-gint
+static gint
 my_list_compare_two (gconstpointer a, gconstpointer b)
 {
   gint one = *((const gint*)a);
@@ -247,14 +242,14 @@ my_list_compare_two (gconstpointer a, gconstpointer b)
   return two-one;
 }
 
-/* void
+/* static void
 my_list_print (gpointer a, gpointer b)
 {
   gint three = *((gint*)a);
   g_print("%d", three);
 }; */
 
-gint
+static gint
 my_compare (gconstpointer a,
 	    gconstpointer b)
 {
@@ -264,7 +259,7 @@ my_compare (gconstpointer a,
   return *cha - *chb;
 }
 
-gint
+static gint
 my_traverse (gpointer key,
 	     gpointer value,
 	     gpointer data)
@@ -299,7 +294,6 @@ main (int   argc,
   GRelation *relation;
   GTuples *tuples;
   gint data [1024];
-  GlibTestInfo *gti;
   struct {
     gchar *filename;
     gchar *dirname;
@@ -910,58 +904,6 @@ main (int   argc,
 #endif
   g_print ("ok\n");
 
-#ifdef G_HAVE_ALLOCA
-  g_print ("checking alloca()-based allocation routines...");
-
-  string = g_alloca(80);
-  g_assert(string != NULL);
-  for (i = 0; i < 80; i++)
-    string[i] = 'x';
-  string[79] = 0;
-  g_assert(strlen(string) == 79);
-
-  gti = g_new_a(GlibTestInfo, 2);
-  string = g_alloca(2);
-  strcpy(string, "x");
-  for (i = 0; i < 2; i++) {
-    for (j = 0; j < 40; j++)
-      gti[i].name[j] = 'x';
-    gti[i].name[39] = 0;
-    g_assert(strlen(gti[i].name) == 39);
-    gti[i].age = 42;
-  }
-  g_assert(strcmp(string, "x") == 0);
-
-  string = g_new0_a(char, 40);
-  for (i = 0; i < 39; i++)
-    string[i] = 'x';
-  g_assert(strlen(string) == 39);
-
-  g_print ("ok\n");
-
-  g_print ("checking alloca()-based string duplication routines...");
-
-  g_strdup_a(string, GLIB_TEST_STRING);
-  g_assert(string != NULL);
-  g_assert(strcmp(string, GLIB_TEST_STRING) == 0);
-  g_strdup_a(string, NULL);
-  g_assert(string == NULL);
-
-  g_strndup_a(string, GLIB_TEST_STRING, 5);
-  g_assert(string != NULL);
-  g_assert(strlen(string) == 5);
-  g_assert(strcmp(string, GLIB_TEST_STRING_5) == 0);
-  g_strndup_a(string, NULL, 20);
-  g_assert(string == NULL);
-
-  g_strconcat3_a(string, GLIB_TEST_STRING, GLIB_TEST_STRING, GLIB_TEST_STRING);
-  g_assert(string != NULL);
-  g_assert(strcmp(string, GLIB_TEST_STRING GLIB_TEST_STRING
-  			  GLIB_TEST_STRING) == 0);
-
-  g_print ("ok\n");
-#endif
-
   return 0;
 }
 
